Class: Google::Cloud::FinancialServices::V1::ListModelsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/financialservices/v1/model.rb

Overview

Request for retrieving a paginated list of Model resources that meet the specified criteria.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Specify a filter to narrow search results.

Returns:

  • (::String)

    Specify a filter to narrow search results.



120
121
122
123
# File 'proto_docs/google/cloud/financialservices/v1/model.rb', line 120

class ListModelsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Specify a field to use for ordering.

Returns:

  • (::String)

    Specify a field to use for ordering.



120
121
122
123
# File 'proto_docs/google/cloud/financialservices/v1/model.rb', line 120

class ListModelsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns The number of resources to be included in the response. The response contains a next_page_token, which can be used to retrieve the next page of resources.

Returns:

  • (::Integer)

    The number of resources to be included in the response. The response contains a next_page_token, which can be used to retrieve the next page of resources.



120
121
122
123
# File 'proto_docs/google/cloud/financialservices/v1/model.rb', line 120

class ListModelsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns In case of paginated results, this is the token that was returned in the previous ListModelsResponse. It should be copied here to retrieve the next page of resources. Empty will give the first page of ListModelsRequest, and the last page will return an empty page_token.

Returns:

  • (::String)

    In case of paginated results, this is the token that was returned in the previous ListModelsResponse. It should be copied here to retrieve the next page of resources. Empty will give the first page of ListModelsRequest, and the last page will return an empty page_token.



120
121
122
123
# File 'proto_docs/google/cloud/financialservices/v1/model.rb', line 120

class ListModelsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent of the Model is the Instance.

Returns:

  • (::String)

    Required. The parent of the Model is the Instance.



120
121
122
123
# File 'proto_docs/google/cloud/financialservices/v1/model.rb', line 120

class ListModelsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end